#include <avr/pgmspace.h>
#include <EEPROM.h>
#include <stdio.h>
#include <TFT_ST7735.h>
#include <SPI.h>

#define DeBounce 20

#define EncPinA  2
#define EncPinB  3
#define EncPress 4

#define EncRED  5
#define EncGRN  6
#define EncBLU  9

#define buzzer A5

#define BacklightPWM 10

volatile byte EncoderPosition;
volatile byte EncoderFirstPos;
volatile int  EncoderDiff = 0;
volatile int  EncodercCount = 0;

#define MSD_CS  A1
#define LCD_CS  A0
#define LCD_DC  A2
#define LCD_RS  A3  // you can also connect this to the Arduino reset

TFT_ST7735 tft = TFT_ST7735(LCD_CS, LCD_DC, LCD_RS);

#define SLR_FOCUS 8
#define SLR_SHOT  7

byte EC_mode=0;
int  EC_delais=3;
byte EC_duree_heure=0;
byte EC_duree_minute=0;
byte EC_duree_seconde=5;
int  EC_duree_milliseconde=0;
byte EC_increment_heure=0;
byte EC_increment_minute=0;
byte EC_increment_seconde=0;
int  EC_increment_milliseconde=0;
byte EC_intervalle_heure=0;
byte EC_intervalle_minute=0;
byte EC_intervalle_seconde=1;
int  EC_intervalle_milliseconde=0;
int  EC_nombre=3;

byte LCD_veille_minute=0;
byte LCD_veille_seconde=0;
byte LCD_jour=1;
byte LCD_lumi=64;
boolean veille_active = false;
unsigned long lastmove = 0;
unsigned long lastpress = 0;

byte SLR_prefocus = 1;
int  SLR_pause_mini_milliseconde = 200;
byte SLR_verr_mirroir = 0;

byte mainmenupos = 0;

uint16_t fgcolor=ST7735_WHITE;

#define EEPROM_VERSION B10101011

#define ARRCHAR 14
#define DOTCHAR 07
#define LCKCHAR 12
#define HRTCHAR 03
#define DRPCHAR 31
#define CHKCHAR 11

void setup(void) {
  pinMode(BacklightPWM  , OUTPUT);
  analogWrite(BacklightPWM,LCD_lumi);
  
  tft.initR(INITR_REDTAB);   // initialize a ST7735R chip, red tab
  
  tft.setRotation(3);
  
  tft.clear();
  
  pinMode(EncPinA, INPUT);
  digitalWrite(EncPinA, HIGH); 
  pinMode(EncPinB, INPUT);
  digitalWrite(EncPinB, HIGH);
  pinMode(EncPress, INPUT);
  digitalWrite(EncPress, HIGH);

  pinMode(SLR_FOCUS, OUTPUT);  
  pinMode(SLR_SHOT , OUTPUT);  
  
  pinMode(EncRED, OUTPUT);
  pinMode(EncGRN, OUTPUT);
  pinMode(EncBLU, OUTPUT);  
  
  pinMode(buzzer, OUTPUT);  

  EncoderFirstPos = (digitalRead(EncPinB) << 1) + digitalRead(EncPinA);;
  EncoderPosition = EncoderFirstPos;

  attachInterrupt(0, ReadEncoderPos, CHANGE);
  attachInterrupt(1, ReadEncoderPos, CHANGE);    
  
  if (EEPROM.read(0) != EEPROM_VERSION)
  {
    FormatEEPROM();  
  }
  else
  {
    Read_EEPROM();
  }
  
  analogWrite(BacklightPWM,LCD_lumi); 
}

void loop() {
  digitalWrite(EncRED, LOW);
  digitalWrite(EncGRN, LOW);
  digitalWrite(EncBLU , LOW);
  digitalWrite(SLR_FOCUS , LOW);  
  digitalWrite(SLR_SHOT  , LOW);  
  main_menu();
}
